@@ -100,12 +100,16 @@ qxgeditApplication::qxgeditApplication ( int& argc, char **argv )
 		// Try own Qt translation...
 		m_pQtTranslator = new QTranslator(this);
 		QString sLocName = "qt_" + loc.name();
+	#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
+		QString sLocPath = QLibraryInfo::path(QLibraryInfo::TranslationsPath);
+	#else
 		QString sLocPath = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
+	#endif
 		if (m_pQtTranslator->load(sLocName, sLocPath)) {
 			QApplication::installTranslator(m_pQtTranslator);
 		} else {
 			delete m_pQtTranslator;
-			m_pQtTranslator = 0;
+			m_pQtTranslator = nullptr;
 		#ifdef CONFIG_DEBUG
 			qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
 				loc.name().toUtf8().constData(),
@@ -124,7 +128,7 @@ qxgeditApplication::qxgeditApplication ( int& argc, char **argv )
 				QApplication::installTranslator(m_pMyTranslator);
 			} else {
 				delete m_pMyTranslator;
-				m_pMyTranslator = 0;
+				m_pMyTranslator = nullptr;
 			#ifdef CONFIG_DEBUG
 				qWarning("Warning: no translation found for '%s' locale: %s/%s.qm",
 					loc.name().toUtf8().constData(),
@@ -459,7 +463,9 @@ int main ( int argc, char **argv )
 #endif
 #endif
 #if QT_VERSION >= QT_VERSION_CHECK(5, 6, 0)
+#if QT_VERSION <  QT_VERSION_CHECK(6, 0, 0)
 	QApplication::setAttribute(Qt::AA_EnableHighDpiScaling);
+#endif
 #endif
 
 	qxgeditApplication app(argc, argv);
