@@ -221,8 +221,11 @@ bool qxgeditOptions::parse_args ( const QStringList& args )
 			return false;
 		}
 		else if (sArg == "-v" || sArg == "--version") {
-			out << QString("Qt: %1\n")
-				.arg(qVersion());
+			out << QString("Qt: %1").arg(qVersion());
+		#if defined(QT_STATIC)
+			out << "-static";
+		#endif
+			out << '\n';
 			out << QString("%1: %2\n")
 				.arg(QXGEDIT_TITLE)
 				.arg(CONFIG_BUILD_VERSION);
