@@ -1,7 +1,7 @@
 // qxgeditUserEg.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -35,7 +35,7 @@ class qxgeditUserEg : public QFrame
 public:
 
 	// Constructor.
-	qxgeditUserEg(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qxgeditUserEg(QWidget *pParent = nullptr);
 	// Destructor.
 	~qxgeditUserEg();
 
